==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsSimpleBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsSimpleBuilder extends LoadBalancerSettingsSimpleFluentImpl<LoadBalancerSettingsSimpleBuilder> implements VisitableBuilder<LoadBalancerSettingsSimple,LoadBalancerSettingsSimpleBuilder>{
  public LoadBalancerSettingsSimpleBuilder() {
    this(false);
  }
  public LoadBalancerSettingsSimpleBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsSimple(), validationEnabled);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimpleFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimpleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsSimple(), validationEnabled);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimpleFluent<?> fluent,LoadBalancerSettingsSimple instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimpleFluent<?> fluent,LoadBalancerSettingsSimple instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withSimple(instance.getSimple());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimple instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimple instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withSimple(instance.getSimple());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsSimpleFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsSimple build() {
    LoadBalancerSettingsSimple buildable = new LoadBalancerSettingsSimple(fluent.getSimple());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsSimpleBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsSimpleBuilder extends LoadBalancerSettingsSimpleFluent<LoadBalancerSettingsSimpleBuilder> implements VisitableBuilder<LoadBalancerSettingsSimple,LoadBalancerSettingsSimpleBuilder>{
  public LoadBalancerSettingsSimpleBuilder() {
    this(false);
  }
  public LoadBalancerSettingsSimpleBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsSimple(), validationEnabled);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimpleFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimpleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsSimple(), validationEnabled);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimpleFluent<?> fluent,LoadBalancerSettingsSimple instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimpleFluent<?> fluent,LoadBalancerSettingsSimple instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LoadBalancerSettingsSimple());

    if (instance != null) {
      fluent.withSimple(instance.getSimple());
      fluent.withSimple(instance.getSimple());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimple instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsSimpleBuilder(LoadBalancerSettingsSimple instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LoadBalancerSettingsSimple());

    if (instance != null) {
      this.withSimple(instance.getSimple());
      this.withSimple(instance.getSimple());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsSimpleFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsSimple build() {
    LoadBalancerSettingsSimple buildable = new LoadBalancerSettingsSimple(fluent.getSimple());
    return buildable;
  }
  
}
